@@ -56,9 +56,7 @@
 #include <dune/uggrid/low/architecture.h>
 #include <dune/uggrid/low/bio.h>
 #include <dune/uggrid/low/debug.h>
-#include <dune/uggrid/low/defaults.h>
 #include <dune/uggrid/low/fileopen.h>
-#include <dune/uggrid/low/general.h>
 #include <dune/uggrid/low/heaps.h>
 #include <dune/uggrid/low/misc.h>
 #include <dune/uggrid/low/namespace.h>
@@ -142,8 +140,6 @@ static INT theBVPDirID;         /*!<  env type for BVP dir
 
 static STD_BVP *currBVP;
 
-REP_ERR_FILE
-
 /****************************************************************************/
 /*                                                                          */
 /* forward declarations of functions used before they are defined	    */
