@@ -30,7 +30,6 @@
 #include <dune/uggrid/ugdevices.h>
 #include <dune/uggrid/low/architecture.h>
 #include <dune/uggrid/low/debug.h>
-#include <dune/uggrid/low/general.h>
 #include <dune/uggrid/low/misc.h>
 
 #include "algebra.h"
@@ -247,7 +246,6 @@ void NS_DIM_PREFIX ListCWofObject (const void *obj, INT offset)
   INT i,n,ce,last_ce,sub,min,cw_objt,oiw;
 
   ASSERT(obj!=NULL);
-  HEAPFAULT(obj);
 
   cw_objt = BITWISE_TYPE(OBJT(obj));
   sub = -1;
@@ -256,7 +254,7 @@ void NS_DIM_PREFIX ListCWofObject (const void *obj, INT offset)
   /* print control word entries in ascending order of offsets in word */
   do
   {
-    min = MAX_I;
+    min = INT_MAX;
     for (i=0; i<MAX_CONTROL_ENTRIES; i++)
       if (control_entries[i].used)
         if (control_entries[i].objt_used & cw_objt)
@@ -271,7 +269,7 @@ void NS_DIM_PREFIX ListCWofObject (const void *obj, INT offset)
               min = oiw;
             }
           }
-    if (min==MAX_I)
+    if (min==INT_MAX)
       break;
 
     n = CW_READ(obj,ce);
@@ -299,7 +297,6 @@ void NS_DIM_PREFIX ListAllCWsOfObject (const void *obj)
   INT i,cw,last_cw,sub,min,cw_objt,offset;
 
   ASSERT(obj!=NULL);
-  HEAPFAULT(obj);
 
   cw_objt = BITWISE_TYPE(OBJT(obj));
   sub = -1;
@@ -308,7 +305,7 @@ void NS_DIM_PREFIX ListAllCWsOfObject (const void *obj)
   /* print control word contents in ascending order of offsets */
   do
   {
-    min = MAX_I;
+    min = INT_MAX;
     for (i=0; i<MAX_CONTROL_WORDS; i++)
       if (control_words[i].used)
         if (control_words[i].objt_used & cw_objt)
@@ -322,7 +319,7 @@ void NS_DIM_PREFIX ListAllCWsOfObject (const void *obj)
             min = offset;
           }
         }
-    if (min==MAX_I)
+    if (min==INT_MAX)
       break;
 
     UserWriteF("cw %s with offset %3d:\n",control_words[cw].name,min);
@@ -359,7 +356,7 @@ static void ListCWofObjectType (INT objt, INT offset, PrintfProcPtr myprintf)
   /* print control word entries in ascending order of offsets in word */
   do
   {
-    min = MAX_I;
+    min = INT_MAX;
     for (i=0; i<MAX_CONTROL_ENTRIES; i++)
       if (control_entries[i].used)
         if (control_entries[i].objt_used & cw_objt)
@@ -374,7 +371,7 @@ static void ListCWofObjectType (INT objt, INT offset, PrintfProcPtr myprintf)
               min = oiw;
             }
           }
-    if (min==MAX_I)
+    if (min==INT_MAX)
       break;
 
     INT_2_bitpattern(control_entries[ce].mask,bitpat);
@@ -415,7 +412,7 @@ static void ListAllCWsOfObjectType (INT objt, PrintfProcPtr myprintf)
   /* print control word contents in ascending order of offsets */
   do
   {
-    min = MAX_I;
+    min = INT_MAX;
     for (i=0; i<MAX_CONTROL_WORDS; i++)
       if (control_words[i].used)
         if (control_words[i].objt_used & cw_objt)
@@ -429,7 +426,7 @@ static void ListAllCWsOfObjectType (INT objt, PrintfProcPtr myprintf)
             min = offset;
           }
         }
-    if (min==MAX_I)
+    if (min==INT_MAX)
       break;
 
     myprintf("cw %-20s with offset in object %3d (UINTs):\n",control_words[cw].name,min);
@@ -661,7 +658,7 @@ UINT NS_DIM_PREFIX ReadCW (const void *obj, INT ceID)
   UINT off_in_obj,mask,i,off_in_wrd,cw,cw_objt;
 
   ASSERT(obj!=NULL);
-  HEAPFAULT(obj);
+
   if ((ceID<0) || (ceID>=MAX_CONTROL_ENTRIES))
   {
     printf("ReadCW: ceID=%d out of range\n",ceID);
@@ -734,7 +731,7 @@ void NS_DIM_PREFIX WriteCW (void *obj, INT ceID, INT n)
   UINT *pcw;
 
   ASSERT(obj!=NULL);
-  HEAPFAULT(obj);
+
   if ((ceID<0) || (ceID>=MAX_CONTROL_ENTRIES))
   {
     printf("WriteCW: ceID=%d out of range\n",ceID);
