@@ -34,10 +34,7 @@
 #include <cstdlib>
 #include <cstddef>
 
-#include <dune/common/unused.hh>
-
 #include <dune/uggrid/low/architecture.h>
-#include <dune/uggrid/low/general.h>
 #include <dune/uggrid/low/misc.h>
 #include <dune/uggrid/ugdevices.h>
 #include <dune/uggrid/low/ugtypes.h>
@@ -81,14 +78,6 @@ const DOUBLE NS_DIM_PREFIX unit_vec[DIM][DIM]={{1,0},{0,1}};
 const DOUBLE NS_DIM_PREFIX unit_vec[DIM][DIM]={{1,0,0},{0,1,0},{0,0,1}};
 #endif
 
-/****************************************************************************/
-/*                                                                          */
-/* definition of variables global to this source file only (static!)        */
-/*                                                                          */
-/****************************************************************************/
-
-REP_ERR_FILE
-
 /****************************************************************************/
 /*                                                                          */
 /* forward declarations of macros                                           */
@@ -147,7 +136,7 @@ REP_ERR_FILE
 
 bool NS_DIM_PREFIX PointInPolygon (const COORD_POINT *Points, INT n, COORD_POINT Point)
 {
-  DUNE_UNUSED DOUBLE D[POLYMAX] ,tau[POLYMAX],xa,ya,xe,ye;
+  [[maybe_unused]] DOUBLE D[POLYMAX] ,tau[POLYMAX],xa,ya,xe,ye;
   int i, left, right;
 
   assert (n<=POLYMAX);
