@@ -49,7 +49,6 @@
 
 #include <dune/common/exceptions.hh>
 #include <dune/common/stdstreams.hh>
-#include <dune/common/unused.hh>
 
 #include <dune/uggrid/parallel/ddd/dddi.h>
 #include "if.h"
@@ -242,7 +241,7 @@ static RETCODE IFCreateFromScratch(DDD::DDDContext& context, COUPLING **tmpcpl,
   IF_ATTR    *ifAttr = nullptr, *lastIfAttr = nullptr;
   int n, i;
   DDD_PROC lastproc;
-  DUNE_UNUSED int STAT_MOD;
+  [[maybe_unused]] int STAT_MOD;
 
   const auto& objTable = context.objTable();
 
