@@ -38,8 +38,6 @@
 #include <cstring>
 #include <cassert>
 
-#include <dune/common/unused.hh>
-
 #include <dune/uggrid/ugdevices.h>
 #include <dune/uggrid/domain/domain.h>
 #include "parallel.h"
@@ -53,7 +51,6 @@
 #include <dune/uggrid/low/architecture.h>
 #include <dune/uggrid/low/debug.h>
 #include <dune/uggrid/low/heaps.h>
-#include <dune/uggrid/low/general.h>
 #include <dune/uggrid/low/namespace.h>
 #include <dune/uggrid/low/ugtypes.h>
 
@@ -159,7 +156,7 @@ static GRID *GetGridOnDemand (MULTIGRID *mg, int level)
   while (level > TOPLEVEL(mg))
   {
     PRINTDEBUG(dddif,1,(PFMT " CreateNewLevel toplevel=%d level=%d",me,TOPLEVEL(mg),level));
-    if (CreateNewLevel(mg,0)==NULL) assert(0);
+    if (CreateNewLevel(mg)==NULL) assert(0);
   }
 
   return GRID_ON_LEVEL(mg,level);
@@ -765,7 +762,7 @@ static void VertexUpdate (DDD::DDDContext& context, DDD_OBJ obj)
 
 static void VertexObjMkCons (DDD::DDDContext&, DDD_OBJ obj, int newness)
 {
-  DUNE_UNUSED VERTEX  *theVertex      = (VERTEX *) obj;
+  [[maybe_unused]] VERTEX *theVertex = (VERTEX *) obj;
 
   PRINTDEBUG(dddif,1,(PFMT " VertexObjMkCons(): v=" VID_FMTX
                       " I/BVOBJ=%d newness=%d\n",
@@ -941,9 +938,6 @@ static void NodeObjMkCons (DDD::DDDContext& context, DDD_OBJ obj, int newness)
 
   /* set pointer of vector to its node */
   if (ddd_ctrl(context).nodeData && NVECTOR(theNode))
-#ifdef __PERIODIC_BOUNDARY__
-    if (VOBJECT(NVECTOR(theNode))==NULL || PRIO((NODE *)VOBJECT(NVECTOR(theNode)))<PRIO(theNode))
-#endif
     VOBJECT(NVECTOR(theNode)) = (GEOM_OBJECT*)theNode;
 
 }
@@ -1136,7 +1130,7 @@ DDD_TYPE NS_DIM_PREFIX NFatherObjType(DDD::DDDContext& context, DDD_OBJ obj, DDD
     if (OBJT((NODE *)ref) != NDOBJ)
       UserWriteF("NFatherObjType(): wrong OBJT=%d\n",OBJT((NODE *)ref));
                         #endif
-    HEAPFAULT(ref);
+
     ASSERT(OBJT((NODE *)ref) == NDOBJ);
     return(dddctrl.TypeNode);
 
@@ -1145,7 +1139,7 @@ DDD_TYPE NS_DIM_PREFIX NFatherObjType(DDD::DDDContext& context, DDD_OBJ obj, DDD
     if (OBJT((EDGE *)ref) != EDOBJ)
       UserWriteF("NFatherObjType(): wrong OBJT=%d\n",OBJT((EDGE *)ref));
                         #endif
-    HEAPFAULT(ref);
+
     ASSERT(OBJT((EDGE *)ref) == EDOBJ);
     return(dddctrl.TypeEdge);
 
@@ -1179,7 +1173,7 @@ static void ElementLDataConstructor (DDD::DDDContext& context, DDD_OBJ obj)
 {
   INT i;
   ELEMENT *pe                     = (ELEMENT *)obj;
-  DUNE_UNUSED INT level           = LEVEL(pe);
+  [[maybe_unused]] INT level      = LEVEL(pe);
   /* TODO: delete
   GRID    *theGrid        = GetGridOnDemand(ddd_ctrl(context).currMG,level);
   INT prio            = EPRIO(pe); */
@@ -1219,7 +1213,7 @@ static void ElementLDataConstructor (DDD::DDDContext& context, DDD_OBJ obj)
 
 static void ElementUpdate (DDD::DDDContext&, DDD_OBJ obj)
 {
-  DUNE_UNUSED ELEMENT *pe                     = (ELEMENT *)obj;
+  [[maybe_unused]] ELEMENT *pe = (ELEMENT *)obj;
 
   PRINTDEBUG(dddif,1,(PFMT " ElementUpdate(): pe=" EID_FMTX
                       " EOBJ=%d\n",me,EID_PRTX(pe),OBJT(pe)))
@@ -2046,7 +2040,7 @@ static void EdgePriorityUpdate (DDD::DDDContext& context, DDD_OBJ obj, DDD_PRIO
 {
   EDGE    *theEdge        = (EDGE *)obj;
   INT level           = LEVEL(theEdge);
-  DUNE_UNUSED INT old                     = PRIO(theEdge);
+  [[maybe_unused]] INT old = PRIO(theEdge);
 
   GetGridOnDemand(ddd_ctrl(context).currMG,level);
 
@@ -2070,7 +2064,7 @@ static void EdgeObjMkCons (DDD::DDDContext& context, DDD_OBJ obj, int newness)
 
 static void EdgeXferCopy (DDD::DDDContext& context, DDD_OBJ obj, DDD_PROC proc, DDD_PRIO prio)
 {
-  DUNE_UNUSED EDGE *pe        =       (EDGE *)obj;
+  [[maybe_unused]] EDGE *pe = (EDGE *)obj;
 
   PRINTDEBUG(dddif,1,(PFMT " EdgeXferCopy(): edge=%x/%08x proc=%d prio=%d\n",
                       me,pe,DDD_InfoGlobalId(PARHDR(pe)),proc,prio));
