@@ -36,7 +36,6 @@
 
 /* low module */
 #include <dune/uggrid/low/debug.h>
-#include <dune/uggrid/low/general.h>
 #include <dune/uggrid/low/heaps.h>
 #include <dune/uggrid/low/misc.h>
 #include <dune/uggrid/low/namespace.h>
@@ -185,8 +184,6 @@ static INT UpdateElementOverlap (DDD::DDDContext& context, ELEMENT *theElement)
                        "SonLevel=%d to dest=%d\n", me,EGID(theSon),theSon,
                        ID(theSon),LEVEL(theSon), EPROCPRIO(context, theNeighbor,PrioMaster)))
 
-      HEAPFAULT(theNeighbor);
-
       if (EPROCPRIO(context, theNeighbor,PrioMaster)>=context.procs()) break;
 
       XFERECOPYX(context, theSon,EPROCPRIO(context, theNeighbor,PrioMaster),PrioHGhost,
@@ -728,7 +725,7 @@ static INT ConnectOverlapVerticalGrid (GRID *theGrid)
                                                                 #ifdef __TWODIM__
               IFDEBUG(dddif,1)
               printf("ConnectOverlapVerticalGrid(): new "
-                     " midnode relation between theEdge=%08p"
+                     " midnode relation between theEdge=%p"
                      " SonNode=" ID_FMTX "Vertex=" VID_FMTX "\n",
                      (void*) theEdge,ID_PRTX(SonNode),
                      VID_PRTX(MYVERTEX(SonNode)));
