@@ -204,7 +204,8 @@ extern DDD_IF BorderNodeIF, BorderNodeSymmIF, OuterNodeIF, NodeVIF,
 extern DDD_IF BorderVectorIF, BorderVectorSymmIF,
               OuterVectorIF, OuterVectorSymmIF,
               VectorVIF, VectorVAllIF, VectorIF;
-extern DDD_IF Facet_InteriorBorder_All_IF;
+extern DDD_IF Facet_All_All_IF,
+              Facet_InteriorBorder_All_IF;
 extern DDD_IF EdgeIF, BorderEdgeSymmIF, EdgeHIF, EdgeVHIF,
               EdgeSymmVHIF;
 
@@ -258,7 +259,8 @@ struct DDD_CTRL
   DDD_IF BorderVectorIF, BorderVectorSymmIF,
          OuterVectorIF, OuterVectorSymmIF,
          VectorVIF, VectorVAllIF, VectorIF;
-  DDD_IF Facet_InteriorBorder_All_IF;
+  DDD_IF Facet_All_All_IF,
+         Facet_InteriorBorder_All_IF;
   DDD_IF VertexIF;
   DDD_IF EdgeIF, BorderEdgeSymmIF, EdgeHIF, EdgeVHIF,
          EdgeSymmVHIF;
@@ -309,7 +311,7 @@ DDD_TYPE        NFatherObjType                  (DDD::DDDContext& context, DDD_O
 void            ObjectPriorityUpdate    (DDD::DDDContext& context, DDD_OBJ obj, DDD_PRIO newPrio);
 
 /* from lbrcb.c */
-int BalanceGridRCB (MULTIGRID *, int);
+void BalanceGridRCB (MULTIGRID *, int);
 
 /* from gridcons.c */
 void    ConstructConsistentGrid                 (GRID *theGrid);
@@ -326,7 +328,6 @@ void    SetGhostObjectPriorities    (GRID *theGrid);
 /* from trans.c */
 int             TransferGrid                            (MULTIGRID *theMG);
 int             TransferGridFromLevel           (MULTIGRID *theMG, INT level);
-void    AMGAgglomerate                          (MULTIGRID *theMG);
 
 /* from identify.c */
 void    IdentifyInit                                    (MULTIGRID *theMG);
