@@ -46,7 +46,6 @@
 #include <dune/uggrid/gm/refine.h>
 #include <dune/uggrid/gm/ugm.h>
 #include <dune/uggrid/low/debug.h>
-#include <dune/uggrid/low/general.h>
 #include <dune/uggrid/low/namespace.h>
 #include <dune/uggrid/low/ugtime.h>
 #include <dune/uggrid/low/ugtypes.h>
@@ -113,55 +112,6 @@ enum GhostCmds { GC_Keep, GC_ToMaster, GC_Delete };
 /****************************************************************************/
 
 
-/****************************************************************************/
-/*
-   AMGAgglomerate -
-
-   SYNOPSIS:
-   void AMGAgglomerate(MULTIGRID *theMG);
-
-   PARAMETERS:
-   .  theMG
-
-   DESCRIPTION:
-
-   RETURN VALUE:
-   void
- */
-/****************************************************************************/
-
-void NS_DIM_PREFIX AMGAgglomerate(MULTIGRID *theMG)
-{
-  INT level,Size;
-  GRID    *theGrid;
-  VECTOR  *theVector;
-
-  DDD::DDDContext& context = theMG->dddContext();
-  const auto master = theMG->ppifContext().master();
-
-  level = BOTTOMLEVEL(theMG);
-  if (level >= 0)
-  {
-    UserWriteF("AMGAgglomerate(): no amg level found, current bottom level is %d\n", level);
-    return;
-  }
-  theGrid = GRID_ON_LEVEL(theMG,level);
-
-  DDD_XferBegin(context);
-  for (theVector=PFIRSTVECTOR(theGrid); theVector!=NULL; theVector=SUCCVC(theVector))
-  {
-    Size = sizeof(VECTOR)-sizeof(DOUBLE)
-           +FMT_S_VEC_TP(MGFORMAT(theMG),VTYPE(theVector));
-    XFERCOPYX(context, theVector,master,PrioMaster,Size);
-    SETPRIO(context, theVector,PrioVGhost);
-  }
-  DDD_XferEnd(context);
-
-  return;
-}
-
-/****************************************************************************/
-
 
 /****************************************************************************/
 /*
@@ -607,7 +557,7 @@ static int XferNodesForOverlap2 (GRID *theGrid)
    .  theGrid
 
    DESCRIPTION:
-   This function sends elements to other procs, keeps overlapping region of one element and maintains correct priorities at interfaces. The destination procs have been computed by theRCB function and put into the elements' PARTITION-entries.
+   This function sends elements to other procs, keeps overlapping region of one element and maintains correct priorities at interfaces. The destination procs have been computed by the RecursiveCoordinateBisection function and put into the elements' PARTITION-entries.
 
    RETURN VALUE:
    void
@@ -825,15 +775,6 @@ int NS_DIM_PREFIX TransferGridFromLevel (MULTIGRID *theMG, INT level)
   trans_begin = CURRENT_TIME;
 #endif
 
-  /* dispose negative levels */
-  if (level < 1)
-    if (DisposeAMGLevels(theMG) != 0)
-      return 1;
-
-        #ifdef __PERIODIC_BOUNDARY__
-  if (MGSetPerVecCount(theMG)) assert(0);
-        #endif
-
   /* send new destination to ghost elements */
   UpdateGhostDests(theMG);
 
